Method: Aws::Honeycode::Client#batch_delete_table_rows
- Defined in:
- lib/aws-sdk-honeycode/client.rb
#batch_delete_table_rows(params = {}) ⇒ Types::BatchDeleteTableRowsResult
The BatchDeleteTableRows API allows you to delete one or more rows from a table in a workbook. You need to specify the ids of the rows that you want to delete from the table.
562 563 564 565 |
# File 'lib/aws-sdk-honeycode/client.rb', line 562 def batch_delete_table_rows(params = {}, = {}) req = build_request(:batch_delete_table_rows, params) req.send_request() end |