Method: Aws::Honeycode::Client#get_screen_data

Defined in:
lib/aws-sdk-honeycode/client.rb

#get_screen_data(params = {}) ⇒ Types::GetScreenDataResult

The GetScreenData API allows retrieval of data from a screen in a Honeycode app. The API allows setting local variables in the screen to filter, sort or otherwise affect what will be displayed on the screen.

Examples:

Request syntax with placeholder values


resp = client.get_screen_data({
  workbook_id: "ResourceId", # required
  app_id: "ResourceId", # required
  screen_id: "ResourceId", # required
  variables: {
    "VariableName" => {
      raw_value: "RawValue", # required
    },
  },
  max_results: 1,
  next_token: "PaginationToken",
})

Response structure


resp.results #=> Hash
resp.results["Name"].headers #=> Array
resp.results["Name"].headers[0].name #=> String
resp.results["Name"].headers[0].format #=> String, one of "AUTO", "NUMBER", "CURRENCY", "DATE", "TIME", "DATE_TIME", "PERCENTAGE", "TEXT", "ACCOUNTING", "CONTACT", "ROWLINK", "ROWSET"
resp.results["Name"].rows #=> Array
resp.results["Name"].rows[0].row_id #=> String
resp.results["Name"].rows[0].data_items #=> Array
resp.results["Name"].rows[0].data_items[0].override_format #=> String, one of "AUTO", "NUMBER", "CURRENCY", "DATE", "TIME", "DATE_TIME", "PERCENTAGE", "TEXT", "ACCOUNTING", "CONTACT", "ROWLINK", "ROWSET"
resp.results["Name"].rows[0].data_items[0].raw_value #=> String
resp.results["Name"].rows[0].data_items[0].formatted_value #=> String
resp.workbook_cursor #=> Integer
resp.next_token #=> String

Parameters:

  • (defaults to: {})

    ({})

Options Hash (params):

  • :workbook_id (required, String)

    The ID of the workbook that contains the screen.

  • :app_id (required, String)

    The ID of the app that contains the screen.

  • :screen_id (required, String)

    The ID of the screen.

  • :variables (Hash<String,Types::VariableValue>)

    Variables are optional and are needed only if the screen requires them to render correctly. Variables are specified as a map where the key is the name of the variable as defined on the screen. The value is an object which currently has only one property, rawValue, which holds the value of the variable to be passed to the screen.

  • :max_results (Integer)

    The number of results to be returned on a single page. Specify a number between 1 and 100. The maximum value is 100.

    This parameter is optional. If you don’t specify this parameter, the default page size is 100.

  • :next_token (String)

    This parameter is optional. If a nextToken is not specified, the API returns the first page of data.

    Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException.

Returns:

See Also:



886
887
888
889
# File 'lib/aws-sdk-honeycode/client.rb', line 886

def get_screen_data(params = {}, options = {})
  req = build_request(:get_screen_data, params)
  req.send_request(options)
end