Method: Aws::Honeycode::Client#get_screen_data
- Defined in:
- lib/aws-sdk-honeycode/client.rb
#get_screen_data(params = {}) ⇒ Types::GetScreenDataResult
The GetScreenData API allows retrieval of data from a screen in a Honeycode app. The API allows setting local variables in the screen to filter, sort or otherwise affect what will be displayed on the screen.
886 887 888 889 |
# File 'lib/aws-sdk-honeycode/client.rb', line 886 def get_screen_data(params = {}, = {}) req = build_request(:get_screen_data, params) req.send_request() end |